@@ -1,7 +1,7 @@
 /*
  * RS-DBI.c
  *
- * $Id: RS-DBI.c 189 2011-10-01 13:16:39Z dirk.eddelbuettel $
+ * $Id: RS-DBI.c 212 2011-11-22 10:58:50Z tomoakin@kenroku.kanazawa-u.ac.jp $
  *
  * This package was developed as a part of Summer of Code program organized by Google.
  * Thanks to David A. James & Saikat DebRoy, the authors of RMySQL package.
@@ -1256,7 +1256,6 @@ RS_na_set(void *ptr, Stype type)
 {
     double *d;
     Sint *i;
-    char *c;
     switch (type) {
     case INTEGER_TYPE:
         i = (Sint *) ptr;
@@ -1270,10 +1269,16 @@ RS_na_set(void *ptr, Stype type)
         d = (double *) ptr;
         *d = NA_REAL;
         break;
+#if 0
+/* this is apparently wrong code and currently NA_SET with STRING_TYPE is not used in the code*/
     case STRING_TYPE:
-        c = (char *) ptr;
-        c = (char *) CHR_EL(NA_STRING, 0);      /*NOTE: modified the RHS by adding cating to (char*) */
-        break;
+        {
+          char *c;
+          c = (char *) ptr;
+          c = (char *) CHR_EL(NA_STRING, 0);      /*NOTE: modified the RHS by adding cating to (char*) */
+          break;
+        }
+#endif
     }
 }
 int
